Struct Image
pub struct Image<'a, Handle = Handle> { /* private fields */ }Expand description
A frame that displays an image while keeping aspect ratio.
Example
use iced::widget::image;
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
image("ferris.png").into()
}
Implementations
impl<'a, Handle> Image<'a, Handle>
impl<'a, Handle> Image<'a, Handle>
pub fn width(self, width: impl Into<Length>) -> Image<'a, Handle>
pub fn width(self, width: impl Into<Length>) -> Image<'a, Handle>
Sets the width of the Image boundaries.
pub fn height(self, height: impl Into<Length>) -> Image<'a, Handle>
pub fn height(self, height: impl Into<Length>) -> Image<'a, Handle>
Sets the height of the Image boundaries.
pub fn expand(self, expand: bool) -> Image<'a, Handle>
pub fn expand(self, expand: bool) -> Image<'a, Handle>
Sets whether the Image should try to fill as much space
available as possible while keeping aspect ratio and without
allocating extra space in any axis with a Length::Shrink
sizing strategy.
This is similar to using Length::Fill for both the
width and the height,
but without the downside of blank space.
pub fn content_fit(self, content_fit: ContentFit) -> Image<'a, Handle>
pub fn content_fit(self, content_fit: ContentFit) -> Image<'a, Handle>
Sets the ContentFit of the Image.
Defaults to ContentFit::Contain
pub fn filter_method(self, filter_method: FilterMethod) -> Image<'a, Handle>
pub fn filter_method(self, filter_method: FilterMethod) -> Image<'a, Handle>
Sets the FilterMethod of the Image.
pub fn opacity(self, opacity: impl Into<f32>) -> Image<'a, Handle>
pub fn opacity(self, opacity: impl Into<f32>) -> Image<'a, Handle>
Sets the opacity of the Image.
It should be in the [0.0, 1.0] range—0.0 meaning completely transparent,
and 1.0 meaning completely opaque.
pub fn crop(self, region: Rectangle<u32>) -> Image<'a, Handle>
pub fn crop(self, region: Rectangle<u32>) -> Image<'a, Handle>
Crops the Image to the given region described by the Rectangle in absolute
coordinates.
Cropping is done before applying any transformation or ContentFit. In practice,
this means that cropping an Image with this method should produce the same result
as cropping it externally (e.g. with an image editor) and creating a new Handle
for the cropped version.
However, this method is much more efficient; since it just leverages scissoring during rendering and no image cropping actually takes place. Instead, it reuses the existing image allocations and should be as efficient as not cropping at all!
The region coordinates will be clamped to the image dimensions, if necessary.
pub fn border_radius(
self,
border_radius: impl Into<Radius>,
) -> Image<'a, Handle>
pub fn border_radius( self, border_radius: impl Into<Radius>, ) -> Image<'a, Handle>
Sets the border::Radius of the Image.
Currently, it will only be applied around the rectangular bounding box
of the Image.
pub fn description_widget<T>(self, description: &T) -> Image<'a, Handle>where
T: Describes,
pub fn description_widget<T>(self, description: &T) -> Image<'a, Handle>where
T: Describes,
Sets the description of the Image.