Struct Scrollable
pub struct Scrollable<'a, Message, Theme = Theme, Renderer = Renderer>{ /* private fields */ }Expand description
A widget that can vertically display an infinite amount of content with a scrollbar.
Example
use iced::widget::{column, scrollable, space};
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
scrollable(column![
"Scroll me!",
space().height(3000),
"You did it!",
]).into()
}Implementations
impl<'a, Message, Theme, Renderer> Scrollable<'a, Message, Theme, Renderer>
impl<'a, Message, Theme, Renderer> Scrollable<'a, Message, Theme, Renderer>
pub fn new(
content: impl Into<Element<'a, Message, Theme, Renderer>>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn new( content: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Scrollable<'a, Message, Theme, Renderer>
Creates a new vertical Scrollable.
pub fn with_direction(
content: impl Into<Element<'a, Message, Theme, Renderer>>,
direction: impl Into<Direction>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn with_direction( content: impl Into<Element<'a, Message, Theme, Renderer>>, direction: impl Into<Direction>, ) -> Scrollable<'a, Message, Theme, Renderer>
Creates a new Scrollable with the given Direction.
pub fn horizontal(self) -> Scrollable<'a, Message, Theme, Renderer>
pub fn horizontal(self) -> Scrollable<'a, Message, Theme, Renderer>
Makes the Scrollable scroll horizontally, with default Scrollbar settings.
pub fn direction(
self,
direction: impl Into<Direction>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn direction( self, direction: impl Into<Direction>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the Direction of the Scrollable.
pub fn id(self, id: impl Into<Id>) -> Scrollable<'a, Message, Theme, Renderer>
pub fn id(self, id: impl Into<Id>) -> Scrollable<'a, Message, Theme, Renderer>
Sets the [widget::Id] of the Scrollable.
pub fn width(
self,
width: impl Into<Length>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn width( self, width: impl Into<Length>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the width of the Scrollable.
pub fn height(
self,
height: impl Into<Length>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn height( self, height: impl Into<Length>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the height of the Scrollable.
pub fn on_scroll(
self,
f: impl Fn(Viewport) -> Message + 'a,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn on_scroll( self, f: impl Fn(Viewport) -> Message + 'a, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets a function to call when the Scrollable is scrolled.
The function takes the Viewport of the Scrollable
pub fn anchor_top(self) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_top(self) -> Scrollable<'a, Message, Theme, Renderer>
Anchors the vertical Scrollable direction to the top.
pub fn anchor_bottom(self) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_bottom(self) -> Scrollable<'a, Message, Theme, Renderer>
Anchors the vertical Scrollable direction to the bottom.
pub fn anchor_left(self) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_left(self) -> Scrollable<'a, Message, Theme, Renderer>
Anchors the horizontal Scrollable direction to the left.
pub fn anchor_right(self) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_right(self) -> Scrollable<'a, Message, Theme, Renderer>
Anchors the horizontal Scrollable direction to the right.
pub fn anchor_x(
self,
alignment: Anchor,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_x( self, alignment: Anchor, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the Anchor of the horizontal direction of the Scrollable, if applicable.
pub fn anchor_y(
self,
alignment: Anchor,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn anchor_y( self, alignment: Anchor, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the Anchor of the vertical direction of the Scrollable, if applicable.
pub fn spacing(
self,
new_spacing: impl Into<Pixels>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn spacing( self, new_spacing: impl Into<Pixels>, ) -> Scrollable<'a, Message, Theme, Renderer>
Embeds the Scrollbar into the Scrollable, instead of floating on top of the
content.
The spacing provided will be used as space between the Scrollbar and the contents
of the Scrollable.
pub fn auto_scroll(
self,
auto_scroll: bool,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn auto_scroll( self, auto_scroll: bool, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets whether the user should be allowed to auto-scroll the Scrollable
with the middle mouse button.
By default, it is disabled.
pub fn scrollbar_width(
self,
width: impl Into<Pixels>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn scrollbar_width( self, width: impl Into<Pixels>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the scrollbar width of the Scrollbar.
pub fn scroller_width(
self,
width: impl Into<Pixels>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn scroller_width( self, width: impl Into<Pixels>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the scroller width of the Scrollbar.
pub fn scrollbar_padding(
self,
padding: impl Into<Pixels>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn scrollbar_padding( self, padding: impl Into<Pixels>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the padding at the start and end of the Scrollbar.
pub fn style(
self,
style: impl Fn(&Theme, Status) -> Style + 'a,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn style( self, style: impl Fn(&Theme, Status) -> Style + 'a, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the style of this Scrollable.
pub fn class(
self,
class: impl Into<<Theme as Catalog>::Class<'a>>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn class( self, class: impl Into<<Theme as Catalog>::Class<'a>>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the style class of the Scrollable.
pub fn name(
self,
name: impl Into<Cow<'a, str>>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn name( self, name: impl Into<Cow<'a, str>>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the name of the Scrollable.
pub fn description_widget(
self,
description: &impl Describes,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn description_widget( self, description: &impl Describes, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the description of the Scrollable.
pub fn description(
self,
description: impl Into<Cow<'a, str>>,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn description( self, description: impl Into<Cow<'a, str>>, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the description of the Scrollable.
pub fn label(
self,
label: &dyn Labels,
) -> Scrollable<'a, Message, Theme, Renderer>
pub fn label( self, label: &dyn Labels, ) -> Scrollable<'a, Message, Theme, Renderer>
Sets the label of the Scrollable.